@@ -70,6 +70,7 @@ class Probe:
         setproctitle(name)
         setup_logger()
         logging.warning(f'starting probe collector: {name} v{version}')
+        self.loop: Optional[asyncio.AbstractEventLoop] = None
         self.name: str = name
         self.version: str = version
         self._checks_funs: Dict[
@@ -134,15 +135,15 @@ class Probe:
         signal.signal(signal.SIGINT, self._stop)
         signal.signal(signal.SIGTERM, self._stop)
 
+        self.loop = asyncio.get_event_loop()
         try:
-            asyncio.run(self._start())
+            self.loop.run_until_complete(self._start())
         except asyncio.exceptions.CancelledError:
-            loop = asyncio.get_event_loop()
-            loop.run_until_complete(loop.shutdown_asyncgens())
-            loop.close()
+            self.loop.run_until_complete(self.loop.shutdown_asyncgens())
+            self.loop.close()
 
     async def _connect(self):
-        conn = asyncio.get_event_loop().create_connection(
+        conn = self.loop.create_connection(
             lambda: AgentcoreProtocol(
                 self._on_set_assets,
                 self._on_unset_assets,
